@@ -1,17 +1,22 @@
 import sys
 import argparse
 from mapula.count import CountMappingStats
+from mapula.merge import MergeMappingStats
+
+USAGE = (
+    """mapping-stats <command> [<args>]"
+
+Available subcommands are:
+    count        Count mapping stats from a SAM/BAM file
+    merge        Combine mapula count's aggregated json outputs
+""")
 
 
 class MappingStats(object):
     def __init__(self):
         parser = argparse.ArgumentParser(
             description="Collects stats from SAM/BAM files",
-            usage="""mapping-stats <command> [<args>]
-
-Available subcommands are:
-   count        Count mapping stats from a SAM/BAM file
-""",
+            usage=USAGE
         )
 
         parser.add_argument("command", help="Subcommand to run")
@@ -27,6 +32,9 @@ Available subcommands are:
     def count(self, argv):
         CountMappingStats.execute(argv)
 
+    def merge(self, argv):
+        MergeMappingStats.execute(argv)
+
 
 def run_main():
     MappingStats()
